
Repudiation attack
-------

**Description:**

A repudiation attack happens when an application or system does not adopt controls to 
properly track and log users actions, thus permitting malicious manipulation or forging 
the identification of new actions. This attack can be used to change the authoring 
information of actions executed by a malicious user in order to log wrong data to log files. 
Its usage can be extended to general data manipulation in the name of others, 
in a similar manner as spoofing mail messages. If this attack takes place, the data stored 
on log files can be considered invalid or misleading. 


**Solution:**

This type of data should always be processed out of reach of the user and should be 
verified and enforced server-side. 

	